@@ -46,7 +46,13 @@ def get_flask_app() -> Flask:
 
 def start_server(host, port, debug=False) -> Flask:    
     app = get_flask_app()
-    app.run(host=host,port=port, debug=debug)
+    print(f"app.template_folder ===>{app.template_folder}")
+    print(f"app.instance_path ===>{app.instance_path}")
+    print(f"app.root_path  ===>{app.root_path}")
+
+    
+    
+    app.run(host=host,port=port, debug=debug)    
     return app
 
 
